==> kstars-0.8.2.tar.gz: kstars-0.8/kstars/skyobjectname.cpp <==
/***************************************************************************
                          skyobjectname.cpp  -  description
                             -------------------
    begin                : Wed Aug 22 2001
    copyright            : (C) 2001 by Jason Harris
    email                : kstars@30doradus.org
 ***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/

#include "skyobjectname.h"

#include <klocale.h>

SkyObjectName::SkyObjectName( const QString &str, SkyObject *obj )
	: skyobject ( obj ), Text ( str )
{
}

SkyObjectName::~SkyObjectName(){
}

SkyObjectNameListItem::SkyObjectNameListItem ( QListBox *parent, SkyObjectName *obj, bool useLatinConstellNames )
	: QListBoxText ( parent ), object ( obj )
{
	if ( useLatinConstellNames )
		setText ( obj->text() );
	else
		setText ( obj->translatedText() );
}


SkyObjectNameListItem::~SkyObjectNameListItem() {
}

==> kstars-0.8.5.tar.gz: kstars-0.8.5/kstars/skyobjectname.cpp <==
/***************************************************************************
                          skyobjectname.cpp  -  description
                             -------------------
    begin                : Wed Aug 22 2001
    copyright            : (C) 2001 by Jason Harris
    email                : kstars@30doradus.org
 ***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/

#include "skyobjectname.h"

#include <klocale.h>

SkyObjectName::SkyObjectName( const QString &str, SkyObject *obj )
	: skyobject ( obj ), Text ( str )
{
}

SkyObjectNameListItem::SkyObjectNameListItem ( QListBox *parent, SkyObjectName *obj, bool useLatinConstellNames )
	: QListBoxText ( parent ), object ( obj )
{
	if ( useLatinConstellNames && obj->skyObject()->type()==-1) //type=-1 == constellation
		setText ( obj->text() );
	else
		setText ( obj->translatedText() );
}
